## Synopsis

ecco_v4_py is a Python package that includes tools for loading and manipulating the ECCO v4 ocean and sea-ice state estimate (http://ecco-group.org)

Extensive documentation is provided on our readthedocs page: 
http://ecco-v4-python-tutorial.readthedocs.io/index.html#

## Installation

Installation instructions can be found here!

https://ecco-v4-python-tutorial.readthedocs.io/Installing_Python_and_Python_Packages.html


## Contributors

If you would like to contribute, consider forking this repository and making pull requests via git!

## Support 

contact ecco-support@mit.edu or Ian.Fenty at jpl.nasa.gov

## License

MIT License
